@@ -31,6 +31,8 @@ sub init {
 
     hook 'after_cart_add' => sub {$self->_after_cart_add(@_)};
     hook 'after_cart_remove' => sub {$self->_after_cart_remove(@_)};
+    hook 'after_cart_rename' => sub {$self->_after_cart_rename(@_)};
+    hook 'after_cart_clear' => sub {$self->_after_cart_clear(@_)};
 }
 
 =head2 load
@@ -130,6 +132,28 @@ sub _after_cart_remove {
     $self->{sqla}->delete('cart_products', {cart => $self->{id}, sku => $item->{sku}});
 }
 
+sub _after_cart_rename {
+    my ($self, @args) = @_;
+
+    unless ($self eq $args[0]) {
+	# not our cart
+	return;
+    }
+
+    $self->{sqla}->update('carts', {name => $args[2]}, {code => $self->{id}});    
+}
+
+sub _after_cart_clear {
+    my ($self, @args) = @_;
+
+    unless ($self eq $args[0]) {
+	# not our cart
+	return;
+    }
+
+    $self->{sqla}->delete('cart_products', {cart => $self->{id}});
+}
+
 =head1 AUTHOR
 
 Stefan Hornburg (Racke), <racke@linuxia.de>
